package com.antai.sport.http.server.game.api.business.sport.user;

import com.antai.sport.http.server.common.annotation.LoginSportUser;
import com.antai.sport.http.server.common.base.Result;
import com.antai.sport.http.server.game.api.business.sport.user.dto.*;
import com.antai.sport.http.server.repository.sport.entity.SportUser;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

import static com.antai.sport.http.server.common.util.ResultUtil.success;

/**
 * @Author liming
 * @Date 2021/8/21 19:41
 * @Email lmmax@126.com
 * @Description:
 */
@RestController
@Api(tags = {"用户相关接口"})
public class SportUserController {

    @Resource
    private SportUserService sportUserService;

    @ApiOperation(value = "登录接口", notes = "登录成功后返回长短token")
    @PostMapping("/login")
    public ResponseEntity<Result<RespLogin>> login(@RequestBody ReqLogin param) {
        return success(sportUserService.login(param));
    }

    @ApiOperation(value = "获取登录短信验证码")
    @GetMapping("/login/sms/captcha/{phone}")
    public ResponseEntity<Result> sendLoginSmsCaptcha(@PathVariable String phone) {
        sportUserService.sendLoginSmsCaptcha(phone);
        return success();
    }

    @ApiOperation(value = "获取用户基本信息所需基础数据")
    @GetMapping("/user/init/info")
    public ResponseEntity<Result<RespRegisterInfo>> getUserInitInfo() {
        return success(sportUserService.getRegisterInfo());
    }

    @ApiOperation(value = "保存用户基本信息")
    @PostMapping("/user/info")
    public ResponseEntity<Result> saveUserInfo(@LoginSportUser SportUser loginUser, @RequestBody ReqSaveUserInfo param) {
        sportUserService.saveUserInfo(loginUser, param);
        return success();
    }

    @ApiOperation(value = "获取用户基本信息")
    @GetMapping("/user/info")
    public ResponseEntity<Result<RespBaseUserInfo>> getUserInfo(@LoginSportUser SportUser loginUser) {
        return success(new RespBaseUserInfo(loginUser));
    }
}
